@@ -83,7 +83,7 @@ def create_image(list_comp_data, path_img, t=0):
         comp_data["mf_server"] = "http://api-magicframe.automusic.win/"
         if comp_data['type'] == "video":
             comp_data['c_type'] = 'image'
-        if comp_data['type'] == "compilation" or comp_data['type'] == "lyric":
+        if comp_data['type'] == "compilation" or comp_data['type'] == "lyric" or comp_data['type'] == 'mix_lyric':
             continue
 
         arr_comps.append(Component.convert(comp_data))
